#
# spec file for package benchmark
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  lib%{name}
%define sover   0
Name:           benchmark
Version:        1.4.0
Release:        lp150.1.1
Summary:        A microbenchmark support library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/google/benchmark
Source:         https://github.com/google/benchmark/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  gmock
BuildRequires:  gtest

%description
A library to support the benchmarking of functions, similar to unit-tests.

%package -n %{soname}%{sover}
Summary:        Shared library for google benchmark
Group:          System/Libraries

%description -n %{soname}%{sover}
A library to support the benchmarking of functions, similar to unit-tests.

%package devel
Summary:        Development files for google benchmark
Group:          Development/Languages/C and C++
Requires:       %{soname}%{sover} = %{version}

%description devel
Development files for google benchmark library

%prep
%setup -q

%build
%if %{__isa_bits} == 64
sed -i 's|lib_install_dir "lib/"|lib_install_dir "lib64/"|g' src/CMakeLists.txt
%endif
%cmake \
  -DBENCHMARK_ENABLE_LTO=off \
  -DBENCHMARK_ENABLE_TESTING=true
%make_jobs

%install
%cmake_install

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_builddir}/%{name}-%{version}/build/src/
%ctest

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license LICENSE
%doc README.md AUTHORS
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%license LICENSE
%doc README.md AUTHORS
%dir %{_prefix}/lib/cmake/
%dir %{_prefix}/lib/cmake/%{name}
%{_prefix}/lib/cmake/%{name}/*.cmake
%{_prefix}/lib/pkgconfig/%{name}.pc
%{_libdir}/%{soname}.so
%{_includedir}/%{name}

%changelog
* Wed Apr  4 2018 avindra@opensuse.org
- Update to version 1.4.0
  * Removal of deprecated headers
  * Improved CPU cache info reporting
  * Support State::KeepRunningBatch()
  * Support int64_t for AddRange()
  * New platform support: NetBSD, s390x, Solaris
  * Bazel build support
  * Support googletest unit tests
  * Add assembler tests
  * Various warnings fixed
- Drop benchmark-s390.patch
  * fixed upstream (commit ff2c255af5bb2fc2e5cd3b3685f0c6283117ce73)
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Remove ExclusiveArch, it works on non-x86 as well
* Fri Mar 16 2018 avindra@opensuse.org
- Update to version 1.3.0:
  * Ranged for loop optimization!
  * Make installation optional
  * Better stats including user-provided ones
  * JSON reporter format fixes
  * Documentation improvements
- Includes changes from 1.2.0:
  * User-defined counters
  * Single header library
  * Ability to clear benchmarks so the runtime registration is more flexible
  * Sample-based standard deviation
  * 32-bit build enabled
  * Bug fixes
- Cleanup with spec-cleaner
- Use %%ctest macro for testing
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 1.1.0:
  * ArgNames support
  * Fixes for OSX and Cygwin and MSVC builds
  * PauseTiming and ResumeTiming are per thread (#286)
  * Better Range and Arg specifications
  * Complexity reporting
* Fri Jan 27 2017 bg@suse.com
- add support for s390x:
  * benchmark-s390.patch
* Sat Nov 12 2016 ro@suse.de
- add ExclusiveArch, package is not ported to anything but
  x86 and x86_64
* Mon Jul  4 2016 mpluskal@suse.com
- Disable lto as it does not seem to go well with -fPIE
* Sat May 14 2016 mpluskal@suse.com
- Initial package for version 1.0.0
